// DCONST.H Header file for general Descent constants/definitions  
// Version 1.01 - 07/11/97
// Summarized by Heiko Herrmann alias HH-Software Images 
// from the Descent Developer Network
// Visit DDN at http://www.delphie.de/descentnet/developer/

typedef signed char    INT8;
typedef signed short   INT16;
typedef signed long    INT32;
typedef unsigned char  UINT8;
typedef unsigned short UINT16;
typedef unsigned long  UINT32;
typedef long           FIX;     /* 16 bits int, 16 bits fraction */
typedef short          FIXANG;  /*  8 bits int,  8 bits fraction */
typedef unsigned int   UINTW;
typedef int            INTW;

typedef struct vms_vector {
  FIX x,y,z;
} VMS_VECTOR;

typedef struct vms_angvec {
  FIXANG p,b,h;
} VMS_ANGVEC;

typedef struct vms_matrix {
  VMS_VECTOR rvec,uvec,fvec;
} VMS_MATRIX;

typedef struct {
  UINT16 index;
} BITMAP_INDEX;

typedef struct shortpos {
  SHORT xo,y0,zo,segment,velx,vely,velz;
} SHORTPOS;
    

// Control types
#define CT_NONE                 0     // doesn't move (or change movement)
#define CT_AI                   1     // driven by AI (=robot)
#define CT_EXPLOSION            2     // explosion sequencer
#define CT_FLYING               4     // the player is flying
#define CT_SLEW                 5     // slewing
#define CT_FLYTHROUGH           6     // the flythrough system
#define CT_WEAPON               9     // laser shots etc.
#define CT_REPAIRCEN           10     // under the control of the repair center
#define CT_MORPH               11     // this object is being morphed
#define CT_DEBRIS              12     // this is a piece of debris
#define CT_POWERUP             13     // animating powerup blob
#define CT_LIGHT               14     // doesn't actually do anything
#define CT_REMOTE              15     // controlled by another net player
#define CT_CNRTLCEN            16     // the control center (main reactor)

// Movement types
#define MT_NONE                0      // doesn't move
#define MT_PHYSICS             1      // moves by physics
#define MT_SPINNING            3      // this object doesn't move just sits and spins

// Render types
#define RT_NONE                0      // does not render    
#define RT_POLYOBJ             1      // a polygon model
#define RT_FIREBALL            2      // a fireball
#define RT_LASER               3      // a laser
#define RT_HOSTAGE             4      // a hostage
#define RT_POWERUP             5      // a powerup
#define RT_MORPH               6      // a robot being morphed
#define RT_WEAPON_VCLIP        7      // a weapon that renders as a vclip
        
// Object types
#define OBJ_NONE             255      // unused object   
#define OBJ_WALL               0      // a wall (not really an object, but used for collisions)
#define OBJ_FIREBALL           1      // a fireball, part of an explosion
#define OBJ_ROBOT              2      // an evil enemy
#define OBJ_HOSTAGE            3      // a hostage you need to rescue
#define OBJ_PLAYER             4      // the player on the console
#define OBJ_WEAPON             5      // a laser, missile, etc.
#define OBJ_CAMERA             6      // a camera to slew around with
#define OBJ_POWERUP            7      // a powerup
#define OBJ_DEBRIS             8      // a piece of robot
#define OBJ_CNTRLCEN           9      // a control center (main reactor)
#define OBJ_FLARE             10      // a flare
#define OBJ_CLUTTER           11      // misc objects
#define OBJ_GHOSTS            12      // what the player turns into when dead
#define OBJ_LIGHT             13      // a light source & not much else
#define OBJ_COOP              14      // a cooperative player object

// Misc object flags
#define OF_EXPLODING           1      // this object is exploding
#define OF_SHOULD_BE_DEAD      2      // this object should be dead, so next time we can we should delete it
#define OF_DESTROYED           4      // this has been killed, and is showing the dead version
#define OF_SILENT              8      // this makes no sound when it hits a wall
#define OF_ATTACHED           16      // this object is a fireball attached to another object
#define OF_HARMLESS           32      // this object does no damage

// Max constants
#define MAX_PRIMARY_WEAPONS   10      // Number of different primary weapon types
#define MAX_SECONDARY_WEAPONS 10      // Number of different secondary weapon types
#define MAX_GUNS               8      // Maximum number of guns a robot can have
#define MAX_CONTROLCEN_GUNS    8      // Maximum number of guns a reactor can have
#define MAX_OBJECT_TYPES      15      // Maximum number of object types
#define MAX_CLIP_FRAMES       50      // Maximum number of frames a VClip/EClip/WClip can have
#define MAX_SUBMODELS         10      // Maximum number of submodels a polygon model can have
#define MAX_ROBOT_TYPES       85      // Maximum number of different robots
#define MAX_ROBOT_JOINTS    1250      // Maximum number of robot joints
#define MAX_POLYGON_MODELS   200      // Maximum number of polygon models
#define MAX_OBJ_BITMAPS      600      // Maximum number of object bitmaps
